"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NODE_MODULES_LOADING_RULES = void 0;
var _getModulePaths = require("../utils/getModulePaths.js");
const makeSwcLoaderConfig = (syntax, jsx) => ({
  loader: 'builtin:swc-loader',
  options: {
    env: {
      targets: {
        'react-native': '0.74'
      }
    },
    jsc: {
      assumptions: {
        setPublicClassFields: true,
        privateFieldsAsProperties: true
      },
      externalHelpers: true,
      parser: syntax === 'js' ? {
        syntax: 'ecmascript',
        jsx: jsx
      } : {
        syntax: 'typescript',
        tsx: jsx
      },
      transform: {
        react: {
          runtime: 'automatic'
        }
      }
    },
    module: {
      type: 'commonjs',
      strict: false,
      strictMode: false,
      noInterop: false
    }
  }
});

/**
 * @constant NODE_MODULES_LOADING_RULES
 * @type {RuleSetRule}
 * @description Module rule configuration for loading node_modules, excluding React Native Core & out-of-tree platform packages.
 */
const NODE_MODULES_LOADING_RULES = exports.NODE_MODULES_LOADING_RULES = {
  type: 'javascript/auto',
  test: /\.[cm]?[jt]sx?$/,
  include: [/node_modules/],
  exclude: (0, _getModulePaths.getModulePaths)(['react', 'react-native', '@react-native', 'react-native-macos', 'react-native-windows', 'react-native-tvos', '@callstack/react-native-visionos']),
  oneOf: [{
    test: /jsx?$/,
    use: [makeSwcLoaderConfig('js', true)]
  }, {
    test: /ts$/,
    use: [makeSwcLoaderConfig('ts', false)]
  }, {
    test: /tsx$/,
    use: [makeSwcLoaderConfig('ts', true)]
  }]
};
//# sourceMappingURL=nodeModulesLoadingRules.js.map